# ooo-dev-tools-gui-win

This package contains Automation for use with LIbreOffice and [OOO Development Tools] project.

## Documentation

Read [Documentation]

## Installation

```sh
pip install ooo-dev-tools-gui-win
```

See Also:

- [OOO Development Tools - Part 3: Draw & Impress](https://python-ooo-dev-tools.readthedocs.io/en/latest/odev/part3/index.html)

[OOO Development Tools]: https://python-ooo-dev-tools.readthedocs.io/en/latest/index.html
[Documentation]: https://ooo-dev-tools-gui-win.readthedocs.io/en/latest/index.html
